<?php
require_once 'vendor/autoload.php';

use TencentCloud\Common\Credential;
use TencentCloud\Common\Profile\ClientProfile;
use TencentCloud\Common\Profile\HttpProfile;
use TencentCloud\Common\Exception\TencentCloudSDKException;
use TencentCloud\Tdmq\V20200217\Models\AcknowledgeMessageRequest;
use TencentCloud\Tdmq\V20200217\Models\CreateSubscriptionRequest;
use TencentCloud\Tdmq\V20200217\Models\ReceiveMessageRequest;
use TencentCloud\Tdmq\V20200217\Models\SendMessagesRequest;
use TencentCloud\Tdmq\V20200217\TdmqClient;
use TencentCloud\Tdmq\V20200217\Models\CreateTopicRequest;

try {
    /**
     * 腾讯云账户SecretId
     * 密钥可前往 https://console.cloud.tencent.com/cam/capi 网站进行获取
     */
    $secretId = "AKIDSiiRtxxxx";
    /** 腾讯云账户SecretKey */
    $secretKey = "GGzSeaM5xxxx";
    /** 云api地址 */
    $endpoint = "tdmq.tencentcloudapi.com";
    /** 集群所属地域参数：参考：https://cloud.tencent.com/document/api/1179/46067#.E5.9C.B0.E5.9F.9F.E5.88.97.E8.A1.A8 */
    $region = "ap-shanghai";
    /** 集群id */
    $clusterId = "pulsar-xxx";
    /** 命名空间名称 */
    $environmentId = "php_http";
    /** topic名称 */
    $topicName = "topic1";
    /** 订阅名称 */
    $subName = "sub";
    /** topic全称, 格式为: 集群（租户）ID/命名空间/Topic名称 */
    $fullTopicName = "pulsar-xxx/php_http/topic1";
    /** 已授权角色密钥 */
    $token = "eyJrZXlJZC......";
    /** 已授权角色名称 */
    $userName = "admin";

    // 认证信息
    $cred = new Credential($secretId, $secretKey);
    $httpProfile = new HttpProfile();
    $httpProfile->setEndpoint($endpoint);

    $clientProfile = new ClientProfile();
    $clientProfile->setHttpProfile($httpProfile);
    // 创建tdmq客户端
    $client = new TdmqClient($cred, $region, $clientProfile);

    /** 创建topic */
    $createTopicReq = new CreateTopicRequest();
    $params = array(
        "EnvironmentId" => $environmentId,
        "TopicName" => $topicName,
        "Partitions" => 3,
        "Remark" => "topic说明信息",
        // 设置topic类型0： 普通消息； 1 ：全局顺序消息(设置全局顺序是，分区数要为0)； 2 ：局部顺序消息；
        "TopicType" => 0,
        "ClusterId" => $clusterId
    );
    $createTopicReq->fromJsonString(json_encode($params));
    $createTopicResp = $client->CreateTopic($createTopicReq);
    print_r($createTopicResp->toJsonString());
    print_r("\n");

    /** 创建订阅 */
    $createSubReq = new CreateSubscriptionRequest();
    $params = array(
        "EnvironmentId" => $environmentId,
        "TopicName" => $topicName,
        "SubscriptionName" => $subName,
        "Remark" => "订阅说明信息",
        "IsIdempotent" => true,
        "ClusterId" => $clusterId,
        // 是否自动创建死信和重试主题，True 表示创建，False表示不创建，默认自动创建死信和重试主题。
        "AutoCreatePolicyTopic" => false,
        // 指定死信和重试主题名称规范，LEGACY表示历史命名规则，COMMUNITY表示Pulsar社区命名规范
        "PostFixPattern" => "COMMUNITY"
    );
    $createSubReq->fromJsonString(json_encode($params));
    $createSubResp = $client->CreateSubscription($createSubReq);
    print_r($createSubResp->toJsonString());
    print_r("\n");

    /** 发送消息 */
    $sendMessageReq = new SendMessagesRequest();
    $params = array(
        "StringToken" => $token,
        "Topic" => $fullTopicName,
        "Payload" => "this is a new message.",
        "ProducerName" => $userName,
        "SendTimeout" => 3000
    );
    $sendMessageReq->fromJsonString(json_encode($params));
    $sendMessageResp = $client->SendMessages($sendMessageReq);
    print_r($sendMessageResp->toJsonString());
    print_r("\n");

    /** 接收消息 */
    $receiveMessageReq = new ReceiveMessageRequest();
    $params = array(
        "Topic" => $fullTopicName,
        "SubscriptionName" => $subName,
        "ReceiverQueueSize" => 10,
        "SubInitialPosition" => "Latest"
    );
    $receiveMessageReq->fromJsonString(json_encode($params));
    $receiveMessageResp = $client->ReceiveMessage($receiveMessageReq);
    print_r($receiveMessageResp->toJsonString());
    print_r("\n");

    /** 确认消息 */
    $ackReq = new AcknowledgeMessageRequest();
    $params = array(
        "MessageId" => $receiveMessageResp->getMessageID(),
        "AckTopic" => $fullTopicName,
        "SubName" => $subName
    );
    $ackReq->fromJsonString(json_encode($params));
    $ackResp = $client->AcknowledgeMessage($ackReq);
    print_r($ackResp->toJsonString());
    print_r("\n");
} catch (TencentCloudSDKException $e) {
    echo $e;
}